@@ -548,7 +548,14 @@ menu_machine_reset( GtkAction *gtk_action GCC_UNUSED, guint action )
   if( hard_reset )
     message = "Hard reset?";
 
-  if( gtkui_confirm( message ) && machine_reset( hard_reset ) ) {
+  if( !gtkui_confirm( message ) )
+    return;
+
+  /* Stop any ongoing RZX */
+  rzx_stop_recording();
+  rzx_stop_playback( 1 );
+
+  if( machine_reset( hard_reset ) ) {
     ui_error( UI_ERROR_ERROR, "couldn't reset machine: giving up!" );
 
     /* FIXME: abort() seems a bit extreme here, but it'll do for now */
