@@ -55,6 +55,10 @@ int utils_read_screen( const char *filename, utils_file *screen );
 
 char* utils_safe_strdup( const char *src );
 
+int
+utils_save_binary( libspectrum_word start, libspectrum_word length,
+                   const char *filename );
+
 void utils_networking_init( void );
 void utils_networking_end( void );
 
